@@ -1,6 +1,6 @@
 package Zabbix::Reporter::Web::Plugin;
 {
-  $Zabbix::Reporter::Web::Plugin::VERSION = '0.05';
+  $Zabbix::Reporter::Web::Plugin::VERSION = '0.06';
 }
 BEGIN {
   $Zabbix::Reporter::Web::Plugin::AUTHORITY = 'cpan:TEX';
@@ -20,7 +20,6 @@ use namespace::autoclean;
 # use Carp;
 # use English qw( -no_match_vars );
 # use Try::Tiny;
-use Zabbix::Reporter;
 
 # extends ...
 # has ...
@@ -43,13 +42,6 @@ has 'tt' => (
     'required'      => 1,
 );
 
-has 'zr' => (
-    'is'            => 'rw',
-    'isa'           => 'Zabbix::Reporter',
-    'lazy'          => 1,
-    'builder'       => '_init_zr',
-);
-
 has 'fields' => (
     'is'            => 'ro',
     'isa'           => 'ArrayRef',
@@ -63,19 +55,14 @@ has 'alias' => (
     'lazy'          => 1,
     'builder'       => '_init_alias',
 );
+
+has 'zr' => (
+    'is'            => 'rw',
+    'isa'           => 'Zabbix::Reporter',
+    'required'      => 1,
+);
 # with ...
 # initializers ...
-sub _init_zr {
-    my $self = shift;
-
-    my $ZR = Zabbix::Reporter::->new({
-        'config'    => $self->config(),
-        'logger'    => $self->logger(),
-    });
-
-    return $ZR;
-}
-
 sub _init_alias { return ''; }
 
 # your code here ...
